"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var index_1 = require("../index");
describe('throws', function () {
    it('catches sync errors', function () {
        var err = index_1.throws(function () { throw new Error('hah'); });
        expect(err.message).toBe('hah');
    });
    it('throws when no error is thrown', function () {
        expect(function () { return index_1.throws(function () { return 42; }); }).toThrow(/supposed/);
    });
    it('catches async errors from functions', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var err;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, index_1.throws(function () { return Promise.reject(new Error('hah')); })];
                case 1:
                    err = _a.sent();
                    expect(err.message).toBe('hah');
                    return [2 /*return*/];
            }
        });
    }); });
    it('reject when an async functions promise resolves', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var err_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    expect.assertions(1);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, index_1.throws(function () { return Promise.resolve(42); })];
                case 2:
                    _a.sent();
                    return [3 /*break*/, 4];
                case 3:
                    err_1 = _a.sent();
                    expect(err_1.message).toMatch(/supposed/);
                    return [3 /*break*/, 4];
                case 4: return [2 /*return*/];
            }
        });
    }); });
    it('catches and returns when passed a promise that rejects', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var err;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, index_1.throws(Promise.reject(new Error('hah')))];
                case 1:
                    err = _a.sent();
                    expect(err.message).toBe('hah');
                    return [2 /*return*/];
            }
        });
    }); });
    it('rejects when passed a promise that resolves', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var err_2;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    expect.assertions(1);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, index_1.throws(Promise.resolve(42))];
                case 2:
                    _a.sent();
                    return [3 /*break*/, 4];
                case 3:
                    err_2 = _a.sent();
                    expect(err_2.message).toMatch(/supposed/);
                    return [3 /*break*/, 4];
                case 4: return [2 /*return*/];
            }
        });
    }); });
    it('uses the specified message', function () {
        expect(function () { return index_1.throws(function () { return 42; }, 'god dammit'); }).toThrow('god dammit');
    });
});
//# sourceMappingURL=index.test.js.map