"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Implememtation.
 * @param fnOrPromise Function or a Promise.
 * @param msg Optional message.
 */
function throws(fnOrPromise, msg) {
    var isFunction = typeof fnOrPromise === 'function';
    var nope = new Error(msg ||
        (isFunction
            ? "The following function was supposed to throw an error:\n" + fnOrPromise
            : 'The Promise was supposed to be rejected'));
    if (isFunction) {
        try {
            var result = fnOrPromise();
            if (result && result.then) {
                return handlePromise(result, nope);
            }
        }
        catch (err) {
            return err;
        }
        throw nope;
    }
    return handlePromise(fnOrPromise, nope);
}
exports.throws = throws;
/**
 * Attaches `then` and `reject` handlers
 * @param p The Promise to handle.
 */
function handlePromise(p, errToThrow) {
    return Promise.resolve()
        .then(function () {
        return p.then(function () { return Promise.reject(errToThrow); });
    })
        .catch(function (err) {
        if (err === errToThrow) {
            throw errToThrow;
        }
        return err;
    });
}
//# sourceMappingURL=index.js.map